@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::App::FromProto;
-$XML::Grammar::Screenplay::App::FromProto::VERSION = '0.24.0';
+$XML::Grammar::Screenplay::App::FromProto::VERSION = '0.26.0';
 use strict;
 use warnings;
 use autodie;
@@ -40,7 +40,7 @@ sub run
         }
     );
 
-    exit(0);
+    return;
 }
 
 1;
@@ -59,7 +59,7 @@ Screenplay XML.
 
 =head1 VERSION
 
-version 0.24.0
+version 0.26.0
 
 =head1 SYNOPSIS
 
